//*********************************************************************
//* COPYRIGHT (C) 1915,2020 TRANSIOM SOFTWARE, INC.                   *
//* ALL RIGHTS RESERVED - PROPERTY OF TRANSIOM SOFTWARE, INC.         *
//*                                                                   *
//* 5698-MG5 COPYRIGHT IBM CORP 2015,2020.                            *
//* ALL RIGHTS RESERVED. LICENSED MATERIAL - PROPERTY OF IBM.         *
//* USE, DUPLICATION OR DISCLOSURE RESTRICTED BY GSA ADP.             *
//*                                                                   *
//* REV. 08/14/2020               WRITTEN BY: SRECKO LAZANJA          *
//*********************************************************************
//*                                                                  *
//* #EZTCOB5 - THIS PROC IS INTERPRETED BY FSYTPA00 DRIVER PROGRAM.  *
//*            INCLUDED IN THIS PROC ARE JOB STEPS AND JCL REQUIRED  *
//*            FOR EMULATING THE "ONE STEP TRANSLATING PROCESS".     *
//*                                                                  *
//*            THIS PROC WAS CREATED TO SUPPORT COBOL V5.1 AND LATER.*
//*            IT IS IDENTICAL WITH #EZTPROC.                        *
//*                                                                  *
//* USAGE: PENGIEZT/MU STANDARD PROC FOR ONGOING SUPPORT OF          *
//*        PROGRAMS WRITTEN IN EASYTRIEVE PLUS SYNTAX.               *
//*                                                                  *
//*        /=> SEE #CNVPROC FOR ONE TIME CONVERSION USE.             *
//*                                                                  *
//* THIS PROC MUST BE TAILORED AT INSTALLATION TIME BY THE INSTALLER.*
//*                                                                  *
//* /=> INSTALLER, FOLLOW IMBEDDED COMMENTS FOR TAILORING DIRECTIONS.*
//*                                                                  *
//* /=> INSTALLER, THE &SYS1 SYMBOL IN THIS PROC IS REPLACED BY THE  *
//*     VALUE IN THE FSYPROCS TABLE/MODULE LOCATED IN &SYS1.SFSYLOAD. *
//*     THE SOURCE CODE FOR FSYPROCS IS LOCATED IN &SYS1.SFSYEZTS.   *
//*                                                                  *
//*           STEP            DESCRIPTION                            *
//*                                                                  *
//*        1. IEFBR14 - DELETE/DEFINE TEMPORARY FILES                *
//*        2. FSCCL1  - TRANSLATES EZT PROGRAM TO PENGIBAT FORMAT    *
//*        3. FSCCL2  - TRANSLATES PENGIBAT PROGRAM TO COBOL         *
//*        4. SQLTRAN - RUNS GENERATED COBOL THRU DB2 TRANSLATOR     *
//*           DYNTRAN - RUNS GENERATED COBOL THRU DYNAMSQL TRANSLATOR*
//*        5. RMU     - COMBINES RMU SCRIPT WITH GENERATED COBOL     *
//*                     (THIS STEP RUNS WHEN RMU REPORTS EXIST       *
//*        6. COBOL   - COMPILES GENERATED COBOL PROGRAM             *
//*        7. LKED    - LINKS COMPILED PROGRAM FOR EXECUTION         *
//*        8. LKGO    - EXECUTES LINKED PROGRAM                      *
//*                                                                  *
//* /=> SQLTRAN STEP IS EXECUTED FOR DB2 PROGRAMS THAT USE           *
//* STATIC BIND ONLY. OTHERWISE, THESE STEPS ARE IGNORED.            *
//*                                                                  *
//* /=> LKED AND LKGO STEPS ARE RUN BASED ON THE PARM LINK (&NAME)   *
//* FOUND IN THE PENGIEZT/MU PROGRAM SOURCE.                         *
//*                                                                  *
//********************************************************************
//* CHANGE HISORY:                                                   *
//*                                                                  *
//* 03/29/2011 - ADDED FJCARD0  DDNAME                               *
//* 08/14/2018 - ADDED SYSUT8-SYSUT15 AND SYSMDECK FOR COBOL V5.1.   *
//* 08/14/2018 - ADDED  DSNTYPE=LIBRARY TO SYSLMOD ON THE LINK STEP  *
//* 09/23/2018 - CHANGED COBOL PROCESS NOADV TO ADV                  *
//* 09/17/2020 - ADDED RMU SUPPORT TO EASYTRIEVE PLUS SYNTAX         *
//********************************************************************
//*                                                                  *
//FSPENGI  PROC ,
//         TWORK=SYSDA,                 UNIT= FOR PENGI WORK
//         CWORK=SYSDA,                 UNIT= FOR COMPILERS
//*-------------------------------------------------------------------*
//         MODEL=&USERID.TEMP,          INTERNAL DATASET NAMES MODEL
//*                                     1ST TWO QUALIFIERS. MAXIMUM
//*                                     LENGTH IS 13 CHARACTERS.
//*                                     &USERID IS REPLACED BY TSO
//*                                     USER BUT IT CAN BE HARD CODED
//*                                     IF MUST DO SO.
//*-------------------------------------------------------------------*
//         EZMACDD=PANDD,               EZT MACROS LIB DDNAME
//*-------------------------------------------------------------------*
//*-- COBOL COMPILER/LINKER DD NAMES TO AVOID CONFLICT ---------------*
//         SYSPRDD=SYSPRINT,            DDNAME FOR SYSPRINT
//         SYSUTDD=SYSUT,               SYSUT1,..SYSUT15 DD NAMES
//*-------------------------------------------------------------------*
//         SVC99=MSGOFF,                DYNAMIC ALLOCATOR MESSAGES
//*                                     MSGOFF = DO NOT PRINT MESSAGES
//*                                     MSGON  = PRINT JES2 MESSAGES
//*                                     MSGALL = PRINT INPUT TEXT +
//*                                              JES2 MESSAGES
//*                                     CAREFUL! TURN MESSAGES ON WHILE
//*                                     TESTING THIS PROC ONLY.
//*-------------------------------------------------------------------*
//*        GENERATOR INTERNAL STEPS START/END MESSAGES
//*     END OF STEP MESSAGES ARE ALWAYS PRINTED FOR RC > 4
//*
//         STEPMSG=END,                 OFF   = NO MESSAGES
//*                                     START = START STEP MSGS ON
//*                                     END   = END OF STEP MSGS ON
//*                                     ALL   = START & END MSS ON
//*-------------------------------------------------------------------*
//*       GENERATOR REQUIRED LIBRARIES (DO NOT CHANGE)                *
//*-------------------------------------------------------------------*
//         PASSWRD=&SYS1.SFSYCCLM,      PASSWORD LOCATION
//         CCL1MAC=&SYS1.SFSYCCLM,      CCL1 MACRO LIBRARY
//         CCL1CPY=&SYS1.SFSYCCLC,      CCL1 COPY LIBRARY
//         CCL1LIB=&SYS1.SFSYLOAD,      PRODUCT LOADLIB
//         FJCCLLB=&SYS1.SFSYFJCC,      COMPILED CCL1 MACROS
//         EASYMAC=&SYS1.SFSYCCLM,      CCL1 MACROS FOR EZT
//         EASYCPY=&SYS1.SFSYEZTC,      EZT COPY/MAC, SQLCA
//         EASYTAB=&SYS1.SFSYEZTS,      EZTABLE0 LIBRARY
//*                                    (SEE COPYNTAB= IN EZPARAMS)
//         REPROLB=&SYS1.SFSYEZTS(#VSMCOPY), REPRO CONTROL STATEMENTS
//*                                    (NEEDED FOR PARALLEL TESTING)
//*-------------------------------------------------------------------*
//*        USER LIBRARY FOR CALLED MODULES                            *
//*     MUST BE REPLACED BY YOUR OWN LIBRARIES                        *
//*         (COMMENT OUT IF NOT NEEDED)                               *
//* ADDITIONAL LIBS CAN BE SUPPLIED VIA SYSLIB IN THE USER JCL        *
//*-------------------------------------------------------------------*
//         OWNLOAD=&SYS1.?????.LOADLIB,     USER INCLUDES
//*                                         (RESOLVES USER CALLS)
//*-------------------------------------------------------------------*
//*   LINK TO LIBRARY (USED BY LKED STEP ONLY)                        *
//*     SYSLMOD MUST BE CODED IN THE USER JCL                         *
//*       (LEAVE THIS STATEMENT COMMENTED OUT)                        *
//*-------------------------------------------------------------------*
//* ??     SYSLMOD=&SYS1.?????.LOADLIB,     LINK TO LOADLIB
//*                                         (USED BY LKED STEP)
//*-------------------------------------------------------------------*
//*             INPUT/OUTPUT LIBRARIES                                *
//*     MUST BE REPLACED BY YOUR OWN LIBRARIES                        *
//*                    NOTE!                                          *
//*     YOU CAN OVERRIDE EZPARMS BY PLACING FJSYSIN IN THE JCL.       *
//*-------------------------------------------------------------------*
//         EZPARMS=&SYS1.SFSYEZTS(EZPARAMS), INPUT EZPARAMS LIB
//         SQLPARM=&SYS1.SFSYEZTS(SQLPARMS), DYNAMSQL SQLPARMS LIB
//*
//*-------------------------------------------------------------------*
//*             DCLGEN LIBRARIES                                      *
//*     MUST BE REPLACED BY YOUR OWN LIBRARIES                        *
//* NEEDED FOR DB2/SQL PROGRAMS ONLY IF CAF IS NOT USED               *
//*       (COMMENT OUT IF NOT USING DB2/SQL)                          *
//*-------------------------------------------------------------------*
//*        DCL1LB=&SYS1.DECLGEN,
//         DCL1LB=&SYS1.SFSYEZTC,
//*
//*-------------------------------------------------------------------*
//*             SQL (DB2) LOAD LIBS                                   *
//*     MUST BE REPLACED BY YOUR OWN LIBRARIES                        *
//*         REQUIRED FOR DB2/SQL PROGRAMS ONY                         *
//*       (COMMENT OUT IF NOT USING DB2/SQL)                          *
//*-------------------------------------------------------------------*
//         DSNLOAD=DB2.V7R1M0.SDSNLOAD,      DB2 / SQL LOAD
//**       DSNEXIT=DB2.V7R1M0.SDSNEXIT,      DB2 / SQL EXIT
//         DSNEXIT=DSN710.SDSNEXIT.DBVA,     DB2 / SQL EXIT
//*
//*-------------------------------------------------------------------*
//*             SQL (DB2) DBRMLIB                                     *
//*     MUST BE REPLACED BY YOUR OWN LIBRARIES                        *
//*       (COMMENT OUT IF NOT USING DB2/SQL)                          *
//*       (!!! LEAVE THIS ITEM COMMENTED OUT)                         *
//*       (DBRMLIB MUST BE PROVIDED IN USER JCL)                      *
//*-------------------------------------------------------------------*
//**       DBRMLIB=???????.MUCONV.DBRMLIB,   USER DBRMLIB
//*
//*-------------------------------------------------------------------*
//*             COBOL COMPILER LIBRARIES                              *
//*     MUST BE REPLACED BY YOUR OWN LIBRARIES                        *
//*-------------------------------------------------------------------*
//         COBLIB=CEE.SCEELKED,              COBOL LE INCLUDES
//*
//*-------------------------------------------------------------------*
//*             IMS INCLUDES LIBRARY                                  *
//*     MUST BE REPLACED BY YOUR OWN LIBRARIES                        *
//*-------------------------------------------------------------------*
//         IMSRLIB=IMS.V6R1M0.RESLIB(DFSLI000),
//*
//*-------------------------------------------------------------------*
//*          COBOL COMPILER AND LINKER OPTIONS                        *
//*         MUST BE REPLACED BY YOUR OWN OPTIONS                      *
//* PROCESS STATEMENT IN EZPARAMS OVERRIDES THESE OPTIONS             *
//*-------------------------------------------------------------------*
//         PRMCOB1='ADV,NOSEQ',
//         PRMCOB2='OBJECT,RENT,NODYNAM,LIB',
//         PRMCOB3='APOST,LIST,MAP,DATA(31),RMODE(24)',
//         PARMLNK='LIST,LET,XREF,MAP,AMODE(ANY),RMODE(24)',
//* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - *
//*       ADDITIONAL OPTIONS                                          *
//* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - *
//         EZTLIST=CND, DEFAULT LIST FOR PENGIEZT/MU FSCCL1 STEP
//*                     VALID OPTIONS: CND/YES/NO. CAN OVERRIDE VIA:
//*                     EASYTRAN: DEBUG (LIST/LISTALL/NOLIST..
//         BATLIST=NO,  DEFAULT LIST FOR PENGIBAT/MU FSCCL2 STEP
//*                     VALID OPTIONS: CND/YES/NO. CAN OVEERIDE VIA:
//*                     EASYTRAN: DEBUG (BLIST/BLISTALL/NOBLIST..
//         ATTACH=,     SQLTRAN ATTACH(CAF)
//*                     THIS OPTION IS OVERRIDEN BY FSYTPA00 BASED ON
//*                     SQLBIND=BIND/&PROG OPTION IN EACYTRAN/EZPARAMS.
//*                     /=>  LEAVE THIS ENTRY AS IS.
//* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - *
//         JCL=NO,      JCL NO/YES (CAN OVERRIDE VIA DABUG (JCL,..
//         DEBUG=N,     DEBUG=Y/N  (CAN OVERRIDE VIA DEBUG (PDEBUG..
//         SYSOUT='*',  SYSOUT DESTINATION
//         MEMBER=GO    DEFAULT MEMBER
//*
//*********************************************************************
//* IEBFR14 - DEFINE/DELETE TEMPORARY FILES.                          *
//*                                                                   *
//* /=> INSTALLER, YOU CAN ACTIVATE IEBFR14 STEP BELOW SHOULD         *
//* DELETE/DEFINE OF ANY TEMPORARY FILES BE NEEDED.                   *
//*********************************************************************
//*IEBFR14  EXEC PGM=IEFBR14
//*
//*********************************************************************
//* FSCCL1 - TRANSLATE EASYTRIEVE STATEMENTS TO PENGIBAT              *
//*********************************************************************
//FSCCL1   EXEC PGM=FSCCOBOL,
// PARM='(COPTION(ERRLIMT=32,LIST=&EZTLIST),SYSPARM(EASYTRAN:&MEMBER))'
//*
//* NOTE: STEPLIB CANNOT BE DYNAMICALLY ALLOCATED. DO NOT CODE IT HERE.
//FJSYSPW  DD  DSN=&PASSWRD(PASSWORD),
//             DISP=SHR
//*
//FJSYSIN  DD  DSN=&EZPARMS,
//             DISP=SHR
//FJCCLLB  DD  DSN=&FJCCLLB,
//             DISP=SHR
//FJMACLB  DD  DSN=&CCL1MAC,
//             DISP=SHR
//         DD  DSN=&EASYMAC,
//             DISP=SHR
//FJCPYLB  DD  DSN=&CCL1CPY,
//             DISP=SHR
//         DD  DSN=&EASYTAB,
//             DISP=SHR
//         DD  DSN=&EASYCPY,
//             DISP=SHR
//         DD  DSN=&DCL1LB,
//             DISP=SHR
//FJCARD0  DD  DSN=&&FJCARD0,
//             DISP=(NEW,CATLG,DELETE),
//             SPACE=(TRK,(1,1),RLSE),
//             UNIT=&TWORK,
//             DCB=(LRECL=80,RECFM=F,BLKSIZE=)
//FJBATPH  DD  UNIT=&TWORK,
//             DSN=&&FJCCL2IN,
//             DISP=(NEW,PASS,DELETE),
//             SPACE=(CYL,(5,10),RLSE),
//             DCB=(LRECL=80,RECFM=FB,BLKSIZE=)
//FJSYS01  DD  UNIT=&TWORK,
//             DSN=&&FJSYS01W,
//             DISP=(NEW,DELETE,DELETE),
//             SPACE=(CYL,5,10),
//             DCB=(BLKSIZE=,LRECL=94,RECFM=FB)
//FJBLUEP  DD  DUMMY
//* NOTE: OVERRIDE FOR FJBIND0 CAN BE PROVIDED IN THE USER JCL
//FJBIND0  DD  UNIT=&TWORK,
//             DSN=&&BINDPRMS,
//             DISP=(NEW,PASS,DELETE),
//             SPACE=(TRK,(5,15),RLSE),
//             DCB=(BLKSIZE=,LRECL=80,RECFM=FB)
//* NOTE: RMU FJRMUP0 SCRIPT SOURCE GENERATED BY THE TRANSLATOR
//* NOTE: OVERRIDE FOR FJRMUP0 CAN BE PROVIDED IN THE USER JCL
//FJRMUP0  DD  UNIT=&TWORK,
//             DSN=&&FJRMUP0,
//             DISP=(NEW,PASS,DELETE),
//             SPACE=(TRK,(5,15),RLSE),
//             DCB=(BLKSIZE=,LRECL=80,RECFM=FB)
//* END OF FJRMUP0 SCRIPT SOURCE GENERATED BY THE TRANSLATOR
//SYSLIST1 DD  SYSOUT=&SYSOUT
//FJSYSER1 DD  SYSOUT=&SYSOUT
//* NOTE: OVERRIDE FOR FJSYSP0 CAN BE PROVIDED IN THE USER JCL
//FJSYSP0  DD  SYSOUT=&SYSOUT
//FJNAMES  DD  SYSOUT=&SYSOUT
//*
//*********************************************************************
//* FSCCL2 - GENERATES COBOL OUT OF PENGIBAT STATEMENTS FROM FSCCL1.  *
//*********************************************************************
//FSCCL2   EXEC PGM=FSCCOBOL,COND=(1,LT,FSCCL1),
//         PARM=(COPTION(LIST=&BATLIST,PARASEQ=(ALL,A,10)),
//               SYSPARM(JCL=&JCL,DEBUG=&DEBUG))
//*
//* NOTE: STEPLIB CANNOT BE DYNAMICALLY ALLOCATED. DO NOT CODE IT HERE.
//FJSYSPW  DD  DSN=&PASSWRD(PASSWORD),
//             DISP=SHR
//FJCCLLB  DD  DSN=&FJCCLLB,
//             DISP=SHR
//FJMACLB  DD  DSN=&CCL1MAC,
//             DISP=SHR
//         DD  DSN=&EASYMAC,
//             DISP=SHR
//FJCPYLB  DD  DSN=&CCL1CPY,
//             DISP=SHR
//         DD  DSN=&EASYCPY,
//             DISP=SHR
//* NOTE: OVERRIDE FOR FJSYSPH CAN BE PROVIDED IN THE USER JCL
//FJSYSPH  DD  UNIT=&TWORK,
//             DSN=&&SQLINPUT,
//             DISP=(NEW,PASS,DELETE),
//             SPACE=(CYL,(5,10),RLSE),
//             DCB=(BLKSIZE=,LRECL=80,RECFM=FB,DSORG=PS)
//FJSYS01  DD  UNIT=&TWORK,
//             DSN=&&FJSYS01W,
//             DISP=(NEW,DELETE,DELETE),
//             SPACE=(CYL,5,10),
//             DCB=(BLKSIZE=,LRECL=94,RECFM=FB)
//SYSLIST2 DD  SYSOUT=&SYSOUT
//FJSYSER2 DD  SYSOUT=&SYSOUT
//FJSYSJC  DD  DUMMY
//FJSYSIN  DD  DSN=&&FJCCL2IN,
//             DISP=(OLD,DELETE,DELETE)
//*
//*********************************************************************
//* DYNTRAN - TRANSLATE STATIC IMBEDDED SQL TO DYNAMIC PREPARE MODE.  *
//*********************************************************************
//DYNTRAN  EXEC PGM=FSCCOBOL,COND=(1,LT,FSCCL2),
//         PARM='(COPTION(LIST=CND),SYSPARM(DYNAMSQL:&MEMBER))'
//*
//* NOTE: STEPLIB CANNOT BE DYNAMICALLY ALLOCATED. DO NOT CODE IT HERE.
//*
//* NOTE: => SYSIN JCL STATEMENT IS NOT NEEDED FOR DYNTRAN. FSYTPA00
//* DYNAMICALLY ALLOCATES SYSIN TO FJSYSPH OF FSCCL2 STEP.
//*
//FJSYSPW  DD  DSN=&PASSWRD(PASSWORD),
//             DISP=SHR
//FJCCLLB  DD  DSN=&FJCCLLB,
//             DISP=SHR
//FJMACLB  DD  DSN=&CCL1MAC,
//             DISP=SHR
//* NOTE: SYSLIB REPLACES FJCPYLB. FJCPYLB FROM FSCCL2 IS FUSED WITH
//* THE SYSLIB BELOW, BY FSYTPA00, TO GAIN ACCESS TO SQL$CA COPYBOOK.
//SYSLIB   DD  DSN=&CCL1CPY,
//             DISP=SHR
//SYSCIN   DD  UNIT=&TWORK,
//             DSN=&&DSNHOUT,
//             DISP=(NEW,PASS,DELETE),
//             DCB=(BLKSIZE=,LRECL=80,RECFM=FB,DSORG=PS)
//             SPACE=(CYL,(5,10),RLSE)
//FJSYS01  DD  UNIT=&TWORK,
//             DSN=&&FJSYS01W,
//             DISP=(NEW,DELETE,DELETE),
//             SPACE=(CYL,5,10),
//             DCB=(BLKSIZE=,LRECL=94,RECFM=FB)
//FJSYSIN  DD  DSN=&SQLPARM,
//             DISP=SHR
//SYSTLIST DD  SYSOUT=&SYSOUT
//SYSTERM  DD  SYSOUT=&SYSOUT
//SYSPRINT DD  UNIT=&TWORK,
//             DSN=&&SQLTLIST,
//             DISP=(NEW,KEEP,DELETE),
//             SPACE=(CYL,(5,10),RLSE)
//*
//*********************************************************************
//*  DB2 PRE-COMPILER. WILL PRE-COMPILE GENERATED COBOL.              *
//*  /=> THIS STEP IS EXECUTED FOR DB2/SQL PROGRAMS ONLY.             *
//*********************************************************************
//SQLTRAN EXEC PGM=DSNHPC,
//             COND=(1,LT,FSCCL2),
// PARM='HOST(COBOL),APOST,APOSTSQL,SOURCE,&ATTACH'
//*
//* NOTE: STEPLIB CANNOT BE DYNAMICALLY ALLOCATED. DO NOT CODE IT HERE.
//*
//* NOTE: => SYSIN JCL STATEMENT IS NOT NEEDED FOR SQLTRAN. FSYTPA00
//* DYNAMICALLY ALLOCATES SYSIN TO FJSYSPH OF FSCCL2 STEP.
//*
//* NOTE: DBRMLIB MUST BE ALLOCATED THRU JCL. DO NOT CODE IT HERE.
//*DBRMLIB  DD  DSN=&DBRMLIB(&MEMBER),
//*             DISP=OLD
//*
//$RUNBYRN DD  DUMMY
//*
//SYSCIN   DD  UNIT=&TWORK,
//             DSN=&&DSNHOUT,
//             DISP=(MOD,PASS,DELETE),
//             SPACE=(CYL,(5,10),RLSE)
//* FJCPYLB FROM FSCCL2 STEP IS CONCATENATED TO SYSLIB BY FSYTPA00
//SYSLIB   DD  DSN=&DCL1LB,
//             DISP=SHR
//         DD  DSN=&EASYCPY,
//             DISP=SHR
//SYSTLIST DD  SYSOUT=&SYSOUT
//SYSTERM  DD  SYSOUT=&SYSOUT
//SYSUT1   DD  SPACE=(CYL,(10,20))
//SYSUT2   DD  SPACE=(CYL,(10,20))
//SYSPRINT DD  UNIT=&TWORK,
//             DSN=&&SQLTLIST,
//             DISP=(NEW,KEEP,DELETE),
//             SPACE=(CYL,(5,10),RLSE)
//*
//*********************************************************************
//*   FZHRMUS0 - HTML GENERATOR SCRIPT DECODER                        *
//*********************************************************************
//FSRMU1   EXEC PGM=FZHRMUS0,PARM=(SYSIN=FJRMUP0,FJSYSPH=FJRMUP1)
//*SYSLIST  DD SYSOUT=&SYSOUT
//RMULIST  DD SYSOUT=&SYSOUT
//RMUERR1  DD SYSOUT=&SYSOUT
//* RMU FJRMUP1 SCRIPT COBOL SOURCE GENERATED BY THE TRANSLATOR
//* NOTE: OVERRIDE FOR FJRMUP1 CAN BE PROVIDED IN THE USER JCL
//FJRMUP1  DD  UNIT=&TWORK,
//             DSN=&&FJRMUP1,
//             DISP=(MOD,CATLG,CATLG),
//             SPACE=(TRK,(5,15),RLSE),
//             DCB=(BLKSIZE=,LRECL=80,RECFM=FB)
//*
//*********************************************************************
//*   COBOL COMPILER WILL COMPILE GENERATED PROGRAM                   *
//*********************************************************************
//COBOL EXEC PGM=IGYCRCTL,
//           COND=(1,LT,FSCCL2),
//           PARM='&PRMCOB1,&PRMCOB2,&PRMCOB3,LIST'
//*
//* NOTE: STEPLIB CANNOT BE DYNAMICALLY ALLOCATED. DO NOT CODE IT HERE.
//*
//* NOTE: => SYSIN JCL STATEMENT IS NOT NEEDED FOR COBOL. FSYTPA00
//* DYNAMICALLY ALLOCATES SYSIN, BASED ON THE PREVIOUSLY PROCESSED
//* STEPS. I.E., FOR DB2, SYSIN IS SWITCHED TO SYSCIN. FOR NON-DB2
//* SYSIN IS SWITCHED TO FJSYSPH OF FSCCL2 STEP.
//SYSPRINT DD  UNIT=&TWORK,
//             DSN=&&COBLIST,
//             DISP=(NEW,KEEP,DELETE),
//             DCB=(LRECL=133,RECFM=FBA,BLKSIZE=26600),
//             SPACE=(CYL,(5,10),RLSE)
//SYSUT1   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT2   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT3   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT4   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT5   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT6   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT7   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//* ADDITIONAL SYSUT AREAS FOR COBOLV5
//SYSUT8   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT9   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT10  DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT11  DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT12  DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT13  DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT14  DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT15  DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSMDECK DD  UNIT=&TWORK,
//             DSN=&&SYSMDEK,
//             DISP=(NEW,CATLG,DELETE),
//             DCB=(BLKSIZE=,LRECL=80,RECFM=FB,DSORG=PS)
//             SPACE=(CYL,(5,10),RLSE)
//SYSPUNCH DD  DUMMY
//SYSLIN   DD  UNIT=&TWORK,
//             DSN=&&LOADSET,
//             DISP=(NEW,PASS,DELETE),
//             SPACE=(CYL,(5,5),RLSE),
//             DCB=(DSORG=PS,RECFM=FB,LRECL=80,BLKSIZE=)
//* FJCPYLB FROM FSCCL2 STEP IS CONCATENATED TO SYSLIB BY FSYTPA00
//SYSLIB   DD  DSN=&CCL1CPY,
//             DISP=SHR
//*
//*********************************************************************
//*  LINK EDIT STEP (LINKS LOAD MODULE)                               *
//*  ==> THIS STEP IS EXECUTED FOR ALL PROGRAMS ONLY WHEN             *
//*     "PARM LINK (&NAME)" IS FOUND IN EZT PLUS SOURCE AND,          *
//*     SYSLMOD IS CODED IN THE USER SUPPLIED JCL.                    *
//*********************************************************************
//LKED     EXEC PGM=IEWL,
//         PARM=(&PARMLNK),
//         COND=(5,LT,COBOL)
//*
//* NOTE: STEPLIB CANNOT BE DYNAMICALLY ALLOCATED. DO NOT CODE IT HERE.
//*
//* NOTE: SYSLMOD MUST BE CODED IN THE USER JCL. DO NOT CODE IT HERE.
//SYSLIN   DD   DSN=&&LOADSET,
//              DISP=(OLD,DELETE,DELETE)
//*
//* SYSLIB FROM USER JCL IS CONCATENATED TO SYSLIB BELOW BY FSYTPA00.
//* /=> INSTALLER, YOU MAY WANT TO REMOVE OR ADD ENTRIES, FROM SYSLIB
//* BELOW, FOR GREATER EXTERNAL FLEXIBILITY, I.E., HAVING LIBRARIES
//* HERE MAY INHIBIT THE ABILITY TO PROVIDE AN OVERRIDE AT RUN TIME.
//SYSLIB   DD   DSN=&COBLIB,
//              DISP=SHR
//         DD   DSN=&CCL1LIB,
//              DISP=SHR
//         DD   DSN=&DSNEXIT,
//              DISP=SHR
//         DD   DSN=&DSNLOAD,
//              DISP=SHR
//         DD   DSN=&IMSRLIB,
//              DISP=SHR
//         DD   DSN=&OWNLOAD,
//              DISP=SHR
//SYSUT1   DD   UNIT=&CWORK,
//              SPACE=(CYL,(7,10),RLSE)
//SYSLMOD  DD   UNIT=&TWORK,
//              DSN=&&SYSLMOD(&MEMBER),
//              DISP=(NEW,KEEP,DELETE),
//              DSNTYPE=LIBRARY,
//              SPACE=(CYL,(5,10,2),RLSE),
//              DCB=(BLKSIZE=,LRECL=32760,RECFM=U)
//SYSPRINT DD   UNIT=&TWORK,
//              DSN=&&LKEDMAP,
//              DISP=(NEW,KEEP,DELETE),
//              SPACE=(CYL,(2,5),RLSE),
//              DCB=(BLKSIZE=,LRECL=121,RECFM=FBA)
//*
//*********************************************************************
//*  LINK AND GO (RUNS COMPILED APPLICATION PROGRAM)                  *
//*  => THIS STEP IS EXECUTED FOR ALL PROGRAMS WHEN THERE IS          *
//*     NO "PARM LINK (&NAME)"  FOUND IN EZT PLUS SOURCE.             *
//*********************************************************************
//LKGO     EXEC PGM=&MEMBER
//*
//* NOTE: STEPLIB CANNOT BE DYNAMICALLY ALLOCATED. DO NOT CODE IT HERE.
//*
// PEND
//*
//
