//*********************************************************************
//* COPYRIGHT 2020, TRANSIOM SOFTWARE, INC.                           *
//* ALL RIGHTS RESERVED - PROPERTY OF TRANSIOM SOFTWARE, INC.         *
//*                                                                   *
//* 5697-P33 COPYRIGHT IBM CORP 2015.                                 *
//* ALL RIGHTS RESERVED. LICENSED MATERIAL - PROPERTY OF IBM.         *
//* USE, DUPLICATION OR DISCLOSURE RESTRICTED BY GSA ADP.             *
//*                                                                   *
//*                               WRITTEN BY: SRECKO LAZANJA          *
//********************************************************************
//*                                                                  *
//* FZH#PROC - THIS PROC IS INTERPRETED BY FZHRMU01 DRIVER PROGRAM.  *
//*            INCLUDED IN THIS PROC ARE JOB STEPS AND JCL REQUIRED  *
//*            FOR EMULATING THE "ONE STEP TRANSLATING PROCESS".     *
//*                                                                  *
//* USAGE: PENGIRMU STANDARD PROC FOR ONGOING SUPPORT OF             *
//*        REPORT MODERNIZATION UTILITY SCRIPT LANGUAGE.             *
//*                                                                  *
//* THIS PROC MUST BE TAILORED AT INSTALLATION TIME BY THE INSTALLER.*
//*                                                                  *
//* /=> INSTALLER, FOLLOW IMBEDDED COMMENTS FOR TAILORING DIRECTIONS.*
//*                                                                  *
//*           STEP            DESCRIPTION                            *
//*                                                                  *
//*        1. FSRMU1  - TRANSLATES SCRIPT LANGUAGE TO COBOL          *
//*        2. COBOL   - COMPILES GENERATED COBOL PROGRAM             *
//*        3. LKED    - LINKS COMPILED PROGRAM FOR EXECUTION         *
//*                                                                  *
//* /=> LKED AND LKGO STEPS ARE RUN BASED ON THE SCRIPT LINK (&NAME) *
//* FOUND IN THE PENGIRMU/RMU PROGRAM SOURCE.                        *
//*                                                                  *
//********************************************************************
//*                                                                  *
//FSPENGI  PROC ,
//         TWORK=SYSDA,                 UNIT= FOR PENGI WORK
//         CWORK=SYSDA,                 UNIT= FOR COMPILERS
//*-------------------------------------------------------------------*
//         MODEL=&USERID.TEMP,          INTERNAL DATASET NAMES MODEL
//*                                     1ST TWO QUALIFIERS. MAXIMUM
//*                                     LENGTH IS 13 CHARACTERS.
//*                                     &USERID IS REPLACED BY TSO
//*                                     USER BUT IT CAN BE HARD CODED
//*                                     IF MUST DO SO.
//*-------------------------------------------------------------------*
//         SYSPRDD=FJSYSPR,             DDNAME FOR COBOL SYSPRINT
//*-------------------------------------------------------------------*
//         SVC99=MSGOFF,                DYNAMIC ALLOCATOR MESSAGES
//*                                     MSGOFF = DO NOT PRINT MESSAGES
//*                                     MSGON  = PRINT JES2 MESSAGES
//*                                     MSGALL = PRINT INPUT TEXT +
//*                                              JES2 MESSAGES
//*                                     CAREFUL! TURN MESSAGES ON WHILE
//*                                     TESTING THIS PROC ONLY.
//*-------------------------------------------------------------------*
//*        GENERATOR INTERNAL STEPS START/END MESSAGES
//*     END OF STEP MESSAGES ARE ALWAYS PRINTED FOR RC > 4
//*
//         STEPMSG=END,                 OFF   = NO MESSAGES
//*                                     START = START STEP MSGS ON
//*                                     END   = END OF STEP MSGS ON
//*                                     ALL   = START & END MSS ON
//*-------------------------------------------------------------------*
//*             COBOL COMPILER LIBRARIES                              *
//*     MUST BE REPLACED BY YOUR OWN LIBRARIES                        *
//*-------------------------------------------------------------------*
//         COBLIB=CEE.SCEELKED,              COBOL LE INCLUDES
//*
//*-------------------------------------------------------------------*
//*          COBOL COMPILER AND LINKER OPTIONS                        *
//*         MUST BE REPLACED BY YOUR OWN OPTIONS                      *
//* PROCESS STATEMENT IN EZPARAMS OVERRIDES THESE OPTIONS             *
//*-------------------------------------------------------------------*
//         PRMCOB1='NOADV,NOSEQ',
//         PRMCOB2='OBJECT,RENT,NODYNAM,LIB',
//         PRMCOB3='APOST,LIST,MAP,DATA(31),RMODE(24)',
//         PARMLNK='LIST,LET,XREF,MAP,AMODE(31),RMODE(ANY)',
//* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - *
//*       ADDITIONAL OPTIONS                                          *
//* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - *
//         SYSOUT='*',  SYSOUT DESTINATION
//         MEMBER=GO    DEFAULT MEMBER
//*
//*********************************************************************
//*   FZHRMUS1 - HTML GENERATOR SCRIPT DECODER                        *
//*********************************************************************
//FSRMU1   EXEC PGM=FZHRMUS1
//SYSLIST  DD SYSOUT=&SYSOUT
//FJSYSPH  DD DSN=&&FJSYSPH,
//         DCB=(LRECL=80,RECFM=FB,BLKSIZE=),
//         DISP=(NEW,CATLG,DELETE),
//         SPACE=(CYL,(5,2))
//*
//*********************************************************************
//*   COBOL COMPILER WILL COMPILE GENERATED PROGRAM                   *
//*********************************************************************
//COBOL EXEC PGM=IGYCRCTL,
//           COND=(1,LT,FSRMU1),
//           PARM='&PRMCOB1,&PRMCOB2,&PRMCOB3,LIST'
//*
//* NOTE: STEPLIB CANNOT BE DYNAMICALLY ALLOCATED. DO NOT CODE IT HERE.
//*
//* NOTE: => SYSIN JCL STATEMENT IS NOT NEEDED FOR COBOL. FZHRMU01
//* DYNAMICALLY ALLOCATES SYSIN, BASED ON THE PREVIOUSLY PROCESSED
//* STEPS. SYSIN IS SWITCHED TO FJSYSPH OF FSRMU1 STEP.
//*
//SYSPRINT DD  UNIT=&TWORK,
//             DSN=&&COBLIST,
//             DISP=(NEW,CATLG,DELETE),
//             DCB=(LRECL=133,RECFM=FBA,BLKSIZE=26600),
//             SPACE=(CYL,(5,10),RLSE)
//SYSUT1   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT2   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT3   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT4   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT5   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT6   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSUT7   DD  UNIT=&CWORK,SPACE=(CYL,(5,10),RLSE)
//SYSPUNCH DD  DUMMY
//SYSLIN   DD  UNIT=&TWORK,
//             DSN=&&LOADSET,
//             DISP=(NEW,CATLG,DELETE),
//             SPACE=(CYL,(5,5),RLSE),
//             DCB=(DSORG=PS,RECFM=FB,LRECL=80,BLKSIZE=)
//SYSIN    DD DSN=&&FJSYSPH,DISP=SHR
//*
//*********************************************************************
//*  LINK EDIT STEP (LINKS LOAD MODULE)                               *
//*  ==> THIS STEP IS EXECUTED FOR ALL PROGRAMS ONLY WHEN             *
//*     "SCRIPT LINK (&NAME) IS FOUND IN THE RMU SCRIPT SOURCE.       *
//*     SYSLMOD IS CODED IN THE USER SUPPLIED JCL.                    *
//*********************************************************************
//LKED     EXEC PGM=IEWL,
//         PARM=(&PARMLNK),
//         COND=(5,LT,COBOL)
//*
//* NOTE: STEPLIB CANNOT BE DYNAMICALLY ALLOCATED. DO NOT CODE IT HERE.
//*
//* NOTE: SYSLMOD MUST BE CODED IN THE USER JCL. DO NOT CODE IT HERE.
//SYSLIN   DD   DSN=&&LOADSET,
//              DISP=(OLD,DELETE,DELETE)
//*
//* SYSLIB FROM USER JCL IS CONCATENATED TO SYSLIB BELOW BY FZHRMU01.
//* /=> INSTALLER, YOU MAY WANT TO REMOVE OR ADD ENTRIES, FROM SYSLIB
//* BELOW, FOR GREATER EXTERNAL FLEXIBILITY, I.E., HAVING LIBRARIES
//* HERE MAY INHIBIT THE ABILITY TO PROVIDE AN OVERRIDE AT RUN TIME.
//SYSLIB   DD   DSN=&COBLIB,
//              DISP=SHR
//SYSUT1   DD   UNIT=&CWORK,
//              SPACE=(CYL,(7,10),RLSE)
//SYSLMOD  DD   UNIT=&TWORK,
//              DSN=&&SYSLMOD(&MEMBER),
//              DISP=(MOD,CATLG,DELETE),
//              SPACE=(CYL,(5,10,2),RLSE),
//              DCB=(BLKSIZE=,LRECL=32760,RECFM=U)
//SYSPRINT DD   UNIT=&TWORK,
//              DSN=&&LKEDMAP,
//              DISP=(NEW,CATLG,DELETE),
//              SPACE=(CYL,(2,5),RLSE),
//              DCB=(BLKSIZE=,LRECL=121,RECFM=FBA)
//*
// PEND
//*
//
